@@ -14,7 +14,7 @@
 #'                       of multilinestrings or \pkg{sp} SpatialLinesDataFrame
 #' @param osm_multipolygons OSM relations as \pkg{sf} Simple Features
 #'                          Collection of multipolygons or \pkg{sp}
-#'                          SpatialPolygonsDataFrame 
+#'                          SpatialPolygonsDataFrame
 #'
 #' @note Class constructor should never be used directly, and is only exported
 #' to provide access to the print method
@@ -22,10 +22,9 @@
 #' @export
 osmdata <- function (bbox = NULL, overpass_call = NULL, meta = NULL,
                      osm_points = NULL, osm_lines = NULL, osm_polygons = NULL,
-                     osm_multilines = NULL, osm_multipolygons = NULL)
-{
-    obj <- list (
-                 bbox = bbox,
+                     osm_multilines = NULL, osm_multipolygons = NULL) {
+
+    obj <- list (bbox = bbox,
                  overpass_call = overpass_call,
                  meta = meta,
                  osm_points = osm_points,
@@ -34,5 +33,6 @@ osmdata <- function (bbox = NULL, overpass_call = NULL, meta = NULL,
                  osm_multilines = osm_multilines,
                  osm_multipolygons = osm_multipolygons)
     class (obj) <- append (class (obj), "osmdata")
+
     return (obj)
 }
