@@ -5,38 +5,38 @@
 #'         text of the message from Overpass and the timestamp of the
 #'         next available slot
 #' @export
-overpass_status <- function (quiet=FALSE)
-{
+overpass_status <- function (quiet=FALSE) {
+
     available <- FALSE
     slot_time <- status <- st_type <- NULL
 
     overpass_url <- get_overpass_url ()
-    st_type <- 'status'
-    if (grepl ('vi-di', overpass_url) | grepl ('rambler', overpass_url)) # nocov
-        st_type <- 'timestamp'                                           # nocov
+    st_type <- "status"
+    if (grepl ("vi-di", overpass_url) | grepl ("rambler", overpass_url)) # nocov
+        st_type <- "timestamp"                                           # nocov
 
-    status_url <- gsub ('interpreter', st_type, overpass_url)
+    status_url <- gsub ("interpreter", st_type, overpass_url)
 
-    if (!curl::has_internet ())
-    {
-        status <- 'No internet connection'      # nocov
+    if (!curl::has_internet ()) {
+
+        status <- "No internet connection"      # nocov
         if (!quiet) message (status)            # nocov
-    } else
-    {
+    } else {
+
         status <- httr::RETRY ("GET", status_url, timeout = 100,
                                times = 10)
-        if (!is.null (status))
-        {
-            status <- httr::content (status, encoding = 'UTF-8')
-            if (st_type == 'status')
+        if (!is.null (status)) {
+
+            status <- httr::content (status, encoding = "UTF-8")
+            if (st_type == "status")
                 slt <- get_slot_time (status = status, quiet = quiet)
-            else if (st_type == 'timestamp')                # nocov
+            else if (st_type == "timestamp")                # nocov
                 slt <- get_slot_timestamp (status = status) # nocov
 
             available <- slt$available
             slot_time <- slt$slot_time
-        } else
-        {
+        } else {
+
             # status not even returned so pause the whole shebang for 10 seconds
             # nocov start
             slot_time <- lubridate::ymd_hms (lubridate::now () + 10)
@@ -51,16 +51,16 @@ overpass_status <- function (quiet=FALSE)
 }
 
 # for APIs with status messages
-get_slot_time <- function (status, quiet)
-{
-    status_now <- strsplit (status, '\n')[[1]][3]
+get_slot_time <- function (status, quiet) {
+
+    status_now <- strsplit (status, "\n")[[1]][3]
     if (!quiet) message (status_now)
 
-    if (grepl ('after', status_now)) {
+    if (grepl ("after", status_now)) {
         # nocov start
         available <- FALSE
-        slot_time <- lubridate::ymd_hms (gsub ('Slot available after: ',
-                                               '', status_now))
+        slot_time <- lubridate::ymd_hms (gsub ("Slot available after: ",
+                                               "", status_now))
         slot_time <- lubridate::force_tz (slot_time,
                                           tz = Sys.timezone ())
         # nocov end
@@ -69,19 +69,19 @@ get_slot_time <- function (status, quiet)
         slot_time <- Sys.time ()
     }
 
-    list ('available' = available, 'slot_time' = slot_time)
+    list ("available" = available, "slot_time" = slot_time)
 }
 
 # For APIs with only timestamps but no status
-get_slot_timestamp <- function (status)
-{
+get_slot_timestamp <- function (status) {
+
     # nocov start
     slot_time <- NA
     available <- FALSE
     if (nchar (status) > 1)
         available <- TRUE
 
-    list ('available' = available, 'slot_time' = slot_time)
+    list ("available" = available, "slot_time" = slot_time)
     # nocov end
 }
 
@@ -92,17 +92,18 @@ get_slot_timestamp <- function (status)
 #' @param return Nothing; stops execution if error encountered.
 #'
 #' @noRd
-check_for_error <- function (doc)
-{
+check_for_error <- function (doc) {
+
     # the nchar check uses an arbitrary value to avoid trying to `read_xml()`
     # read data, which would take forever.
     # nocov start
     if (grepl ("error: ", doc, ignore.case = TRUE) &
-        nchar (doc) < 10000)
-    {
+        nchar (doc) < 10000) {
+
         docx <- xml2::read_xml (doc)
-        if (xml2::xml_length (docx) < 10) # arbitrarily low value
-        {
+
+        if (xml2::xml_length (docx) < 10) { # arbitrarily low value
+
             remark <- xml2::xml_text (xml2::xml_find_all (docx, "remark"))
             if (length (remark) > 1)
                 stop (paste0 ("overpass", remark))
@@ -135,33 +136,33 @@ check_for_error <- function (doc)
 #'
 #' @noRd
 overpass_query <- function (query, quiet = FALSE, wait = TRUE, pad_wait = 5,
-                            encoding = 'UTF-8') {
+                            encoding = "UTF-8") {
 
     if (missing (query))
-        stop ('query must be supplied', call. = FALSE)
+        stop ("query must be supplied", call. = FALSE)
     if (!is.character (query) | length (query) > 1)
-        stop ('query must be a single character string')
+        stop ("query must be a single character string")
 
     if (!is.logical (quiet))
         quiet <- FALSE
     if (!is.logical (wait))
         wait <- TRUE
-    if (!is.numeric (pad_wait))
-    {
-        message ('pad_wait must be numeric; setting to 5s')
+    if (!is.numeric (pad_wait)) {
+
+        message ("pad_wait must be numeric; setting to 5s")
         pad_wait <- 5
     }
-    if (pad_wait < 0)
-    {
-        warning ('pad_wait must be positive; setting to 5s')
+    if (pad_wait < 0) {
+
+        warning ("pad_wait must be positive; setting to 5s")
         pad_wait <- 5
     }
 
     if (!curl::has_internet ())
-        stop ('Overpass query unavailable without internet',    # nocov
+        stop ("Overpass query unavailable without internet",    # nocov
               call. = FALSE)                                    # nocov
 
-    if (!quiet) message('Issuing query to Overpass API ...')
+    if (!quiet) message("Issuing query to Overpass API ...")
 
     o_stat <- overpass_status (quiet)
 
@@ -172,23 +173,23 @@ overpass_query <- function (query, quiet = FALSE, wait = TRUE, pad_wait = 5,
     } else {
         if (wait) {
             wait <- max(0, as.numeric (difftime (o_stat$next_slot, Sys.time(),
-                                                 units = 'secs'))) + pad_wait
-            message (sprintf ('Waiting %s seconds', wait))
+                                                 units = "secs"))) + pad_wait
+            message (sprintf ("Waiting %s seconds", wait))
             Sys.sleep (wait)
             res <- httr::POST (overpass_url, body = query)
         } else {
-            stop ('Overpass query unavailable', call. = FALSE)
+            stop ("Overpass query unavailable", call. = FALSE)
         }
     }
-    if (!quiet) message ('Query complete!')
+    if (!quiet) message ("Query complete!")
 
-    if (class (res) == 'result') # differs only for mock tests
+    if (class (res) == "result") # differs only for mock tests
         httr::stop_for_status (res)                             # nocov
 
-    else if (class (res) == 'raw') # for mock tests
+    else if (class (res) == "raw") # for mock tests
         doc <- rawToChar (res)
     else
-        doc <- httr::content (res, as = 'text', encoding = encoding,
+        doc <- httr::content (res, as = "text", encoding = encoding,
                               type = "application/xml")
     # TODO: Just return the direct httr::POST result here and convert in the
     # subsequent functions (`osmdata_xml/csv/sp/sf`)?
