@@ -1,9 +1,7 @@
 context ("sc-osm")
 
-# test_all used to switch off tests on CRAN
 test_all <- (identical (Sys.getenv ("MPADGE_LOCAL"), "true") |
-             identical (Sys.getenv ("TRAVIS"), "true"))
-             #identical (Sys.getenv ("APPVEYOR"), "True"))
+             identical (Sys.getenv ("GITHUB_WORKFLOW"), "test-coverage"))
 
 # Current names of SC objects as returned by osmdata:
 sc_names <- c ("nodes", "relation_members", "relation_properties",
