@@ -1,9 +1,7 @@
 context ("sf-osm")
 
-# test_all used to switch off tests on CRAN
 test_all <- (identical (Sys.getenv ("MPADGE_LOCAL"), "true") |
-             identical (Sys.getenv ("TRAVIS"), "true"))
-             #identical (Sys.getenv ("APPVEYOR"), "True"))
+             identical (Sys.getenv ("GITHUB_WORKFLOW"), "test-coverage"))
 
 test_that ("multipolygon", {
                x_sf <- sf::st_read ("../osm-multi.osm",
@@ -22,8 +20,7 @@ test_that ("multipolygon", {
                # but sf now also inserts default row.names that are numeric
                # rather than character, so
                class (attributes (x)$row.names) <- "integer"
-               for (i in seq (length (x$geometry [[1]])))
-               {
+               for (i in seq (length (x$geometry [[1]]))) {
                    names (x$geometry [[1]] [[i]]) <- NULL
                    for (j in seq (length (x$geometry [[1]] [[i]])))
                        dimnames (x$geometry [[1]] [[i]] [[j]]) <- NULL
@@ -40,7 +37,7 @@ test_that ("multipolygon", {
                attrs <- names (attributes (g))
                #if (!test_all) # CRS is no longer idencial because x has
                # proj4strin
-                   attrs <- attrs [attrs != 'crs']
+                   attrs <- attrs [attrs != "crs"]
                for (a in attrs)
                    expect_identical (attr (g, a), attr (g_sf, a))
 })
@@ -57,8 +54,7 @@ test_that ("multilinestring", {
                x_sf <- x_sf [, which (names (x_sf) %in% names (x))]
                rownames (x_sf) <- rownames (x)
                names (x$geometry [[1]]) <- NULL
-               for (i in seq (length (x$geometry [[1]])))
-               {
+               for (i in seq (length (x$geometry [[1]]))) {
                    names (x$geometry [[1]] [[i]]) <- NULL
                    dimnames (x$geometry [[1]] [[i]]) <- NULL
                }
@@ -73,7 +69,7 @@ test_that ("multilinestring", {
                g_sf <- x_sf$geometry
                attrs <- names (attributes (g))
                #if (!test_all)
-                   attrs <- attrs [attrs != 'crs']
+                   attrs <- attrs [attrs != "crs"]
                for (a in attrs)
                    expect_identical (attr (g, a), attr (g_sf, a))
 })
@@ -93,7 +89,7 @@ test_that ("ways", {
                    dimnames (x$geometry [[i]]) <- NULL
                # Then names also need to be removed from each non-sfc column
                for (i in 1:(ncol (x) - 1))
-                   names (x [[names (x)[i] ]]) <- NULL
+                   names (x [[names (x) [i] ]]) <- NULL # nolint
                # These last lines change the order of attributes, # so they are
                # reset here
                attributes (x) <- attributes (x) [match (attributes (x_sf),
@@ -108,7 +104,7 @@ test_that ("ways", {
                g_sf <- x_sf$geometry
                attrs <- names (attributes (g))
                #if (!test_all)
-                   attrs <- attrs [attrs != 'crs']
+                   attrs <- attrs [attrs != "crs"]
                for (a in attrs)
                    expect_identical (attr (g, a), attr (g_sf, a))
 })
